<?php

/*-----------------------------------------------------------------------------------*/
/* Load Theme Options Page
/*-----------------------------------------------------------------------------------*/

$functions_path = TEMPLATEPATH . '/functions/';
require_once ( $functions_path . 'theme-options.php' );


/*-----------------------------------------------------------------------------------*/
/* Version cache for custom stylesheets and custom javascript files
/*-----------------------------------------------------------------------------------*/

function wap8_version_cache() {
	return '2.4.4';
}

/*-----------------------------------------------------------------------------------*/
/* Periodic Theme Setup
/*-----------------------------------------------------------------------------------*/

add_action( 'after_setup_theme', 'wap8_periodic_theme_setup' );

function wap8_periodic_theme_setup() {

	// Set the $content_width
	global $content_width;
	if ( !isset( $content_width ) ) $content_width = 620;

	// Add custom editor styles
	add_editor_style( 'periodic-editor-style.css' );
	
	// Add theme support for automatic-feed-links
	add_theme_support( 'automatic-feed-links' );
	
	// Add theme support for post-thumbnails
	add_theme_support( 'post-thumbnails' );
	
	// Add action for custom menus
	add_action( 'init', 'periodic_register_menus' );
	
	// Add action for registering sidebars
	add_action( 'widgets_init', 'periodic_register_sidebars' );
	
	// Add action for registering, deregistering and enqueueing global javascripts
	add_action( 'init', 'wap8_register_js' );
	
	// Add action for registering, deregistering and enqueueing global stylesheets
	add_action( 'init', 'wap8_register_css' );
	
	// Add filter for custom excerpt length
	add_filter( 'excerpt_length', 'wap8_excerpt_length' );
	
	// Add filter for custom excerpt more string
	add_filter( 'excerpt_more', 'wap8_excerpt_more' );
	
	// Add filter for browser specific body class
	add_filter( 'body_class' , 'wap8_browser_body_class' );
	
	// Add filter for xmlns declaration
	add_filter( 'language_attributes', 'wap8_html_declaration' );
	
	// Load Twitter Feed widget
	require_once( TEMPLATEPATH . '/widgets/widget-twitter.php' );
	
	// Load Flickr Feed widget
	require_once( TEMPLATEPATH . '/widgets/widget-flickr.php' );
	
	// Load Custom Categories widget
	require_once( TEMPLATEPATH . '/widgets/widget-customcategories.php' );
	
	// Load Recent Video widget
	require_once( TEMPLATEPATH . '/widgets/widget-recentvideo.php' );
	
	// Load Search Form widget
	require_once( TEMPLATEPATH . '/widgets/widget-searchform.php' );
	
	// Load Tabs widget
	require_once( TEMPLATEPATH . '/widgets/widget-tabs.php' );
	
	// Load Recent Posts from Current Categories widget
	require_once( TEMPLATEPATH . '/widgets/widget-rpcurrentcat.php' );
	
	// Load 125x125 Ad widget
	require_once( TEMPLATEPATH . '/widgets/widget-125banner.php' );
	
	// Allow shortcodes in 125x125 Ad widgets
	add_filter( 'wap8_125_ad_widget', 'do_shortcode' );
	
	// Load 120x240 Ad widget
	require_once( TEMPLATEPATH . '/widgets/widget-120banner.php' );
	
	// Allow shortcodes in 120x240 Ad widgets
	add_filter( 'wap8_120_ad_widget', 'do_shortcode' );
	
	// Load 120x600 Ad widget
	require_once( TEMPLATEPATH . '/widgets/widget-120skyscraper.php' );
	
	// Allows shortcodes in 120x600 Ad widgets
	add_filter( 'wap8_120_sky_widget', 'do_shortcode' );
	
	// Load 300x250 Ad widget
	require_once( TEMPLATEPATH . '/widgets/widget-300banner.php' );
	
	// Allow shortcodes in 300x250 Ad widgets
	add_filter( 'wap8_300_ad_widget', 'do_shortcode' );
	
	// Load 300x600 Ad widget
	require_once( TEMPLATEPATH . '/widgets/widget-300half.php' );
	
	// Allow shortcodes in 300x60 Ad widgets
	add_filter( 'wap8_300_half_widget', 'do_shortcode' );
	
	// Allow shortcodes in text widgets
	add_filter( 'widget_text', 'do_shortcode' );
	
	// Add action for theme options link in admin nav bar
	add_action( 'wp_before_admin_bar_render', 'periodic_options_link' );
	
	// Add pull quote right shortcode
	add_shortcode( 'pullright', 'pull_quote_right' );
	
	// Add pull quote left shortcode
	add_shortcode( 'pullleft', 'pull_quote_left' );
	
	// Add checklist shortcode
	add_shortcode( 'checklist', 'checklist' );
	
	// Add arrow list shortcode
	add_shortcode( 'arrowlist', 'arrowlist' );
	
	// Add note shortcode
	add_shortcode( 'note', 'note' );
	
	// Add two column shortcode
	add_shortcode( 'two_column', 'two_column' );
	
	// Add two column last shortcode
	add_shortcode( 'two_column_last', 'two_column_last' );
	
	// Add three column shortcode
	add_shortcode( 'three_column', 'three_column' );
	
	// Add three column last shortcode
	add_shortcode( 'three_column_last', 'three_column_last' );
	
	// Add four column shortcode
	add_shortcode( 'four_column', 'four_column' );
	
	// Add four column last shortcode
	add_shortcode( 'four_column_last', 'four_column_last' );
	
	// Add button shortcode
	add_shortcode( 'button', 'button' );
	
	// Add filter for trackback subtraction from comments
	add_filter( 'get_comments_number', 'periodic_comment_count', 0);
	
	// Add filters for fancybox linked images
	add_filter('the_content', 'addfancyboxrel_replace', 12);
	add_filter('get_comment_text', 'addfancyboxrel_replace');
	
	// Load textdomain for localization
	load_theme_textdomain( 'periodic', TEMPLATEPATH.'/languages' );

}


/*-----------------------------------------------------------------------------------*/
/* Set post thumbnail image sizes
/*-----------------------------------------------------------------------------------*/

set_post_thumbnail_size(150, 150, true); // Standard Thumbnail Size
add_image_size('thumbnail-archive', 270, 120, true); // Archives Thumbnail Size
add_image_size('thumbnail-feature', 390, 280, true); // Features Thumbnail Size
add_image_size('thumbnail-featurenav', 130, 60, true); // Feature Slider Nav Thumbnail Size
add_image_size('thumbnail-leadimg', 610, 225, true); // Lead Image Thumbnail Size
add_image_size('thumbnail-search', 130, 130, true); // Search Results Thumbnail Size
add_image_size('thumbnail-sidebar', 60, 60, true); // Sidebar Thumbnail Size
add_image_size('thumbnail-sidebarvid', 290, 215, true); // Sidebar Video Thumbnail Size
add_image_size('thumbnail-sticky', 210, 100, true); // Sticky Post Thumbnail Size
add_image_size('thumbnail-home', 290, 125, true); // Home lead Category Block Thumbnail Size

/*-----------------------------------------------------------------------------------*/
/* Register WP 3+ custom menus
/*-----------------------------------------------------------------------------------*/

function periodic_register_menus() {
	if ( function_exists( 'register_nav_menus' ) ) {
		register_nav_menus(
			array(
				'utility-menu' => __( 'Utility Menu','periodic' ),
				'main-menu' => __( 'Main Menu','periodic' ),
			)		
		);
	}
}

/*-----------------------------------------------------------------------------------*/
/* Fallback Page Menu
/*-----------------------------------------------------------------------------------*/
function periodic_page_menu() {
	echo '<ul class="header-menu">';
	wp_list_pages('title_li=');
	echo '</ul>';
}

/*-----------------------------------------------------------------------------------*/
/* Fallback Category Menu
/*-----------------------------------------------------------------------------------*/
function periodic_category_menu() {
	echo '<ul>';
	wp_list_categories('title_li=');
	echo '</ul>';
}

/*-----------------------------------------------------------------------------------*/
/* Register sidebars
/*-----------------------------------------------------------------------------------*/

function periodic_register_sidebars() {

	// Register sidebar for Home Page
	register_sidebar(
		array(
			'id' => 'home',
			'name' => __( 'Sidebar for Home Page', 'periodic' ),
			'description' => __( 'Drag, organize and save widgets for the sidebar that will appear on your Home page.', 'periodic' ),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-head">',
			'after_title' => '</h3>'
		)
	);

	// Register Right Sidebar
	register_sidebar(
		array(
			'id' => 'right',
			'name' => __( 'Right Sidebar', 'periodic' ),
			'description' => __( 'Drag, organize and save widgets for the Right Sidebar.', 'periodic' ),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-head">',
			'after_title' => '</h3>'
		)
	);
	
	// Register Left Sidebar
	register_sidebar(
		array(
			'id' => 'left',
			'name' => __( 'Left Sidebar', 'periodic' ),
			'description' => __( 'Drag, organize and save widgets for the Left Sidebar.', 'periodic' ),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-head">',
			'after_title' => '</h3>'
		)
	);
	
	// Register Footer Column 1
	register_sidebar(
		array(
			'id' => 'footer-column-one',
			'name' => __( 'Footer Column One', 'periodic' ),
			'description' => __( 'Drag, organize and save widgets for the first Footer Column.', 'periodic' ),
			'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3>',
			'after_title' => '</h3>'
		)
	);
	
	// Register Footer Column 2
	register_sidebar(
		array(
			'id' => 'footer-column-two',
			'name' => __( 'Footer Column Two', 'periodic' ),
			'description' => __( 'Drag, organize and save widgets for the second Footer Column.', 'periodic' ),
			'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3>',
			'after_title' => '</h3>'
		)
	);
	
	// Register Footer Column 3
	register_sidebar(
		array(
			'id' => 'footer-column-three',
			'name' => __( 'Footer Column Three', 'periodic' ),
			'description' => __( 'Drag, organize and save widgets for the third Footer Column.', 'periodic' ),
			'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3>',
			'after_title' => '</h3>'
		)
	);
	
}

/*-----------------------------------------------------------------------------------*/
/* Register, deregister and enqueue global javascripts
/*-----------------------------------------------------------------------------------*/

function wap8_register_js() {
	if ( !is_admin() ) {
		// Register javascripts
		wp_deregister_script( 'jquery' );
		wp_register_script( 'jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.4.4/jquery.min.js', '', '1.4.4', false );
		wp_register_script( 'jquery-easing', get_template_directory_uri() . '/js/jquery.easing.1.3.min.js', 'jquery', '1.3', true );
		wp_register_script( 'jquery-cycle', get_template_directory_uri() . '/js/jquery.cycle.all.min.js', array( 'jquery', 'jquery-easing' ), '2.99', true );
		wp_register_script( 'jquery-fancybox', get_template_directory_uri() . '/js/jquery.fancybox-1.3.4.min.js', array( 'jquery', 'jquery-easing' ), '1.3.4', true );
		wp_register_script( 'jquery-superfish', get_template_directory_uri() . '/js/jquery.superfish-1.4.8.min.js', 'jquery', '1.4.8', true );
		wp_register_script( 'jquery-supersubs', get_template_directory_uri() . '/js/jquery.supersubs-0.2b.min.js', array( 'jquery', 'jquery-superfish' ), '0.2b', true );
		wp_register_script( 'periodic-jquery', get_template_directory_uri() . '/js/periodic.js', array( 'jquery', 'jquery-easing', 'jquery-cycle', 'jquery-fancybox', 'jquery-superfish', 'jquery-supersubs', 'jquery-ui-core', 'jquery-ui-widget', 'jquery-ui-tabs' ), wap8_version_cache(), true );
		wp_register_script( 'digg-share', get_template_directory_uri() . '/js/digg.js', array( 'jquery', 'periodic-jquery') , wap8_version_cache(), true );
		wp_register_script( 'twitter-platform-script', 'http://platform.twitter.com/widgets.js', array( 'jquery', 'periodic-jquery' ), wap8_version_cache(), true );
		wp_register_script( 'google-plus-script', get_template_directory_uri() . '/js/google-plusone.js', array( 'jquery', 'periodic-jquery' ), wap8_version_cache(), true );
		
		// Enqueue javascripts
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'periodic-jquery' );
		wp_enqueue_script( 'jquery-easing' );
		wp_enqueue_script( 'jquery-cycle' );
		wp_enqueue_script( 'jquery-fancybox' );
		wp_enqueue_script( 'jquery-superfish' );
		wp_enqueue_script( 'jquery-supersubs' );
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-widget' );
		wp_enqueue_script( 'jquery-ui-tabs' );
		
	}
}

/*-----------------------------------------------------------------------------------*/
/* Register, deregister and enqueue global stylesheets
/*-----------------------------------------------------------------------------------*/

function wap8_register_css() {
	if ( !is_admin() ) {
		// Register core stylesheet
		wp_register_style( 'periodic-core', get_template_directory_uri() . '/style.css', '', wap8_version_cache(), 'screen' );
		wp_register_style( 'periodic-print', get_template_directory_uri() . '/css/print.css', 'periodic-core', wap8_version_cache(), 'print' );
		wp_register_style( 'black-blue', get_template_directory_uri() . '/css/black-blue.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'black-green', get_template_directory_uri() . '/css/black-green.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'black-orange', get_template_directory_uri() . '/css/black-orange.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'black-pink', get_template_directory_uri() . '/css/black-pink.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'black-purple', get_template_directory_uri() . '/css/black-purple.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'black-red', get_template_directory_uri() . '/css/black-red.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'legacy-blue', get_template_directory_uri() . '/css/blue.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'legacy-green', get_template_directory_uri() . '/css/green.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'legacy-orange', get_template_directory_uri() . '/css/orange.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'legacy-pink', get_template_directory_uri() . '/css/pink.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'legacy-purple', get_template_directory_uri() . '/css/purple.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'legacy-red', get_template_directory_uri() . '/css/red.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'spectrum-blue', get_template_directory_uri() . '/css/spectrum-blue.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'spectrum-green', get_template_directory_uri() . '/css/spectrum-green.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'spectrum-orange', get_template_directory_uri() . '/css/spectrum-orange.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'spectrum-pink', get_template_directory_uri() . '/css/spectrum-pink.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'spectrum-purple', get_template_directory_uri() . '/css/spectrum-purple.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'spectrum-red', get_template_directory_uri() . '/css/spectrum-red.css', 'periodic-core', wap8_version_cache(), 'screen' );
		wp_register_style( 'fancybox-styles', get_template_directory_uri() . '/fancybox/jquery.fancybox-1.3.4.css', '', '1.3.4', 'screen' );
		
		
		// Enqueue stylesheets
		wp_enqueue_style( 'fancybox-styles' );
		
		wp_enqueue_style( 'periodic-print' );
		
		if ( get_option( 'wap8_css' ) == 'Black and Blue' ) {
			wp_enqueue_style( 'black-blue' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Black and Green' ) {
			wp_enqueue_style( 'black-green' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Black and Orange' ) {
			wp_enqueue_style( 'black-orange' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Black and Pink' ) {
			wp_enqueue_style( 'black-pink' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Black and Purple' ) {
			wp_enqueue_style( 'black-purple' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Black and Red' ) {
			wp_enqueue_style( 'black-red' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Legacy Blue' ) {
			wp_enqueue_style( 'legacy-blue' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Legacy Green' ) {
			wp_enqueue_style( 'legacy-green' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Legacy Orange' ) {
			wp_enqueue_style( 'legacy-orange' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Legacy Pink' ) {
			wp_enqueue_style( 'legacy-pink' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Legacy Purple' ) {
			wp_enqueue_style( 'legacy-purple' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Legacy Red' ) {
			wp_enqueue_style( 'legacy-red' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Dark Spectrum Blue' ) {
			wp_enqueue_style( 'spectrum-blue' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Dark Spectrum Green' ) {
			wp_enqueue_style( 'spectrum-green' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Dark Spectrum Orange' ) {
			wp_enqueue_style( 'spectrum-orange' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Dark Spectrum Pink' ) {
			wp_enqueue_style( 'spectrum-pink' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Dark Spectrum Purple' ) {
			wp_enqueue_style( 'spectrum-purple' );
		}
		
		elseif ( get_option( 'wap8_css' ) == 'Dark Spectrum Red' ) {
			wp_enqueue_style( 'spectrum-red' );
		}
		
	}
}

/*-----------------------------------------------------------------------------------*/
/* Custom excerpt length
/*-----------------------------------------------------------------------------------*/

function wap8_excerpt_length($length) {
	return 35;
}

/*-----------------------------------------------------------------------------------*/
/* Custom excerpt more string
/*-----------------------------------------------------------------------------------*/

function wap8_excerpt_more($more) {
	return '&#8230;';
}

/*-----------------------------------------------------------------------------------*/
/* Add browser specific classes to body tag
/*-----------------------------------------------------------------------------------*/

function wap8_browser_body_class($classes) {
    global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;

    if ( $is_lynx ) $classes[] = 'lynx';
    elseif ( $is_gecko ) $classes[] = 'gecko';
    elseif ( $is_opera ) $classes[] = 'opera';
    elseif ( $is_NS4 ) $classes[] = 'ns4';
    elseif ( $is_safari ) $classes[] = 'safari';
    elseif ( $is_chrome ) $classes[] = 'chrome';
    elseif ( $is_IE ) $classes[] = 'ie';
    else $classes[] = 'unknown';

    if ( $is_iphone ) $classes[] = 'iphone';
    return $classes;
}

/*-----------------------------------------------------------------------------------*/
/* Add valid declarations to html tag
/*-----------------------------------------------------------------------------------*/

function wap8_html_declaration($output) {
	$output = 'xmlns="http://www.w3.org/1999/xhtml" dir="ltr" lang="en-US" xml:lang="en-US"';
	return $output;
}

/*-----------------------------------------------------------------------------------*/
/* Add Theme Options link to WordPress Admin Nav Bar
/*-----------------------------------------------------------------------------------*/

function periodic_options_link() {
	global $wp_admin_bar;
	
	$wp_admin_bar -> add_menu( array(
		'parent' => 'appearance',
		'id' => 'periodic_options_link',
		'title' => __( 'Periodic Settings', 'periodic' ),
		'href' => admin_url( 'themes.php?page=theme-options.php' )
	));
}
	
/*-----------------------------------------------------------------------------------*/
/* Periodic Shortcodes
/*-----------------------------------------------------------------------------------*/

// Pull quote right shortcode
function pull_quote_right($atts, $content=null) {
	extract(shortcode_atts(array(
		'float' => '$align',
	), $atts));
	return '<blockquote class="pullquote pullright ' . $float . '">' . $content . '</blockquote>';
}

// Pull quote left shortcode
function pull_quote_left($atts, $content=null) {
	extract(shortcode_atts(array(
		'float' => '$align',
	), $atts));
	return '<blockquote class="pullquote pullleft ' . $float . '">' . $content . '</blockquote>';
}

// Check list shortcode
function checklist($atts, $content=null) {
	$content = preg_replace( '#^<\/p>|^<br \/>|<p>$#', '', $content );
	return '<div class="checklist">' . $content . '</div>';
}

// Arrow list shortcode
function arrowlist($atts, $content=null) {
	$content = preg_replace( '#^<\/p>|^<br \/>|<p>$#', '', $content );
	return '<div class="arrowlist">' . $content . '</div>';
}

// Note shortcode
function note($atts, $content=null) {
	return '<div class="note">' . $content . '</div>';
}

// Two column shortcode
function two_column($atts, $content=null) {
	$content = preg_replace( '#^<br \/>|<br>$#', '', $content );
	return '<div class="two_column">' . $content . '</div>';
}

// Two column last shortcode
function two_column_last($atts, $content=null) {
	$content = preg_replace( '#^<br \/>|<br>$#', '', $content );
	return '<div class="two_column_last">' . $content . '</div>';
}

// Three column shortcode
function three_column($atts, $content=null) {
	$content = preg_replace( '#^<br \/>|<br>$#', '', $content );
	return '<div class="three_column">' . $content . '</div>';
}

// Three column last shortcode
function three_column_last($atts, $content=null) {
	$content = preg_replace( '#^<br \/>|<br>$#', '', $content );
	return '<div class="three_column_last">' . $content . '</div>';
}

// Four column shortcode
function four_column($atts, $content=null) {
	$content = preg_replace( '#^<br \/>|<br>$#', '', $content );
	return '<div class="four_column">' . $content . '</div>';
}

// Four column last shortcode
function four_column_last($atts, $content=null) {
	$content = preg_replace( '#^<br \/>|<br>$#', '', $content );
	return '<div class="four_column_last">' . $content . '</div>';
}

// Button shortcode
function button($atts, $content = null) {
	extract(shortcode_atts(array(
		'url' => '',
	), $atts));
	return '<a class="button" href="'.$url.'" title="'.$content.'">'.$content.'</a>';
}

/*-----------------------------------------------------------------------------------*/
/* Subtract trackback totals from comment totals
/*-----------------------------------------------------------------------------------*/

function periodic_comment_count( $count ) {
	if ( ! is_admin() ) {
	global $id;
		$comments_by_type = &separate_comments(get_comments('status=approve&post_id=' . $id));
		return count($comments_by_type['comment']);
	} else {
		return $count;
		}
	}
						
/*-----------------------------------------------------------------------------------*/
/* Periodic Breadcrumbs
/*-----------------------------------------------------------------------------------*/

function periodic_breadcrumbs() {
 
  $delimiter = '&#47;';
  $name = get_bloginfo('name'); //text for the 'Home' link
  $currentBefore = '<span class="current-crumb">';
  $currentAfter = '</span>';
 
  if ( !is_home() && !is_front_page() || is_paged() ) {
 
    echo '<div id="breadcrumbs"><p>';
 
    global $post;
    $home = home_url();
    echo '<a href="' . $home . '" title="' . $name .'">' . $name . '</a> ' . $delimiter . ' ';
 
    if ( is_category() ) {
      global $wp_query;
      $cat_obj = $wp_query->get_queried_object();
      $thisCat = $cat_obj->term_id;
      $thisCat = get_category($thisCat);
      $parentCat = get_category($thisCat->parent);
      if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
      echo $currentBefore;
      single_cat_title();
      echo $currentAfter;
 
    } elseif ( is_day() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
      echo $currentBefore . get_the_time('d') . $currentAfter;
 
    } elseif ( is_month() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo $currentBefore . get_the_time('F') . $currentAfter;
 
    } elseif ( is_year() ) {
      echo $currentBefore . get_the_time('Y') . $currentAfter;
      
	} elseif ( is_single() && !is_attachment() ) {
		if ( get_post_type() != 'post' ) {
			$post_type = get_post_type_object( get_post_type() );
			$slug = $post_type->rewrite;
			echo '<a href="' . $home . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a> ' . $delimiter . ' ';
			echo $currentBefore . get_the_title() . $currentAfter;
		} else {
			$cat = get_the_category(); $cat = $cat[0];
			echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
			echo $currentBefore . get_the_title() . $currentAfter;
      }
 
    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
      $post_type = get_post_type_object(get_post_type());
      echo $currentBefore . $post_type->labels->singular_name . $currentAfter;
 
    } elseif ( is_attachment() ) {
      $parent = get_post($post->post_parent);
      $cat = get_the_category($parent->ID); $cat = $cat[0];
      echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
      echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
      echo $currentBefore;
      the_title();
      echo $currentAfter;
 
    } elseif ( is_page() && !$post->post_parent ) {
      echo $currentBefore;
      the_title();
      echo $currentAfter;
 
    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
      echo $currentBefore;
      the_title();
      echo $currentAfter;
 
    } elseif ( is_search() ) {
      echo $currentBefore . __('Search Results for &ldquo;', 'periodic') . get_search_query() . '&rdquo;' . $currentAfter;
 
    } elseif ( is_tag() ) {
      echo $currentBefore;
      single_tag_title();
      $currentAfter;
 
    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $currentBefore . __('Articles Posted by ','periodic') . $userdata->display_name . $currentAfter;
 
    } elseif ( is_404() ) {
      echo $currentBefore . __('404 Error: Page Not Found', 'periodic') . $currentAfter;
    }
 
    if ( get_query_var('paged') ) {
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' &#151; <span class="current-crumb">';
      echo __('Page','periodic') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo '</span>';
    }
 
    echo '</p></div>';
 
  }
}

/*-----------------------------------------------------------------------------------*/
/* Custom comments callback
/*-----------------------------------------------------------------------------------*/

function periodic_comments($comment, $args, $depth) {
$GLOBALS['comment'] = $comment; ?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
	<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<p><?php echo get_avatar($comment,$size='50',$default=get_option('wap8_comment_avatar') ); ?></p>
		</div>
 
		<div class="comment-body clear">
			<div class="comment-meta commentmetadata">
			<?php printf(__('<cite class="comment-cite">%s</cite>'), get_comment_author_link()) ?>
				<p><?php printf(__('%1$s at %2$s','periodic'), get_comment_date(),get_comment_time()) ?></p>
				<p><?php edit_comment_link(__('(Edit)','periodic'),'  ','') ?></p>
			</div>
 		
 			<div class="comment-text">
			<?php if ($comment->comment_approved == '0') : ?>
				<p><em><?php _e('Your comment is awaiting moderation.','periodic') ?></em></p>
			<?php endif; ?>
		
			<?php comment_text() ?>
			</div>
		
			<?php if($args['max_depth']!=$depth) { ?>
			<div class="reply">
				<p><?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></p>
			</div>
		</div>
<?php } ?>
	</div>
<?php
}

/*-----------------------------------------------------------------------------------*/
/* Custom trackbacks callback
/*-----------------------------------------------------------------------------------*/

function periodic_trackbacks($comment) {
$GLOBALS['comment'] = $comment; ?>
<li><?php printf(__('<cite class="trackback-cite">%s</cite>'), get_comment_author_link()) ?> <?php edit_comment_link(__('(Edit)','periodic'),'  ','') ?></li>
<?php
}

/*-----------------------------------------------------------------------------------*/
/* Add a rel="fancybox-gallery" tag to all linked image files
/*-----------------------------------------------------------------------------------*/

function addfancyboxrel_replace ($content) {
	global $post;
	$pattern = "/<a(.*?)href=('|\")([^>]*).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>(.*?)<\/a>/i";
    $replacement = '<a$1href=$2$3.$4$5 rel="fancybox-gallery"$6>$7</a>';
    $content = preg_replace($pattern, $replacement, $content);
    return $content;
}

/*-----------------------------------------------------------------------------------*/
/* List admins, contributors, editors and authors for contributors template
/*-----------------------------------------------------------------------------------*/

function periodic_contributors() {
	global $wpdb;
	
	$authors = $wpdb->get_results("
		SELECT  ID, display_name
		FROM wp_users
		INNER JOIN wp_usermeta
		ON wp_users.ID  = wp_usermeta.user_id
			WHERE wp_usermeta.meta_key = 'wp_capabilities'
		AND (wp_usermeta.meta_value
			LIKE '%admin%'
			OR wp_usermeta.meta_value
			LIKE '%contributor%'
			OR wp_usermeta.meta_value
			LIKE '%editor%'
			OR wp_usermeta.meta_value
			LIKE '%author%' )
		ORDER BY display_name
		");

		foreach($authors as $author) {
			echo "<li>";
				echo '<div class="contribute-avatar"';
				echo "<a href=\"" . home_url() ."/author/"; the_author_meta('user_nicename', $author->ID); echo "/\">";
				echo get_avatar($author->ID, '75');
				echo "</a>";
				echo "</div>";
				echo '<div class="contribute-text">';
				echo "<h3><a href=\"". home_url() ."/author/"; the_author_meta('user_nicename', $author->ID); echo "/\">"; the_author_meta('display_name', $author->ID);
				echo "</a></h3>";
				echo "<p>";
				echo the_author_meta('description', $author->ID);
				echo "</p>";
				echo "<p>";
				echo _e('Browse Articles by ','periodic');
				echo "<a class=\"right-arrow\" href=\"". home_url() ."/author/"; the_author_meta('user_nicename', $author->ID); echo "/\">"; the_author_meta('display_name', $author->ID);
				echo "</a>";				
				echo "</p>";
				echo "</div>";
			echo "</li>";
		}
	}

/*-----------------------------------------------------------------------------------*/
/* Misc. URL's used throughtout the theme
/*-----------------------------------------------------------------------------------*/

// We Are Pixel8 ThemeForest URL	
function wap8_tf_url() {
	return '"http://themeforest.net/user/wearepixel8"';
}

// We Are Pixel8 Twitter URL
function wap8_twitter_url() {
	return '"http://twitter.com/wearepixel8"';
}

// We Are Pixel8 website URL
function wap8_site_url() {
	return '"http://www.wearepixel8.com"';
}

// Twitter Share URL
function wap8_twitter_share_url() {
	return '"http://twitter.com/share"';
}

// Flickr IDGettr URL
function wap8_flickr_idgettr_url() {
	return '"http://idgettr.com/"';
}

?>