<?php

/*
Plugin Name: Custom Categories Sidebar Widget
Plugin URI: http://www.wearepixel8.com
Description: A widget that will display a customized categories list for your sidebar.
Version: 1.0
Author: We Are Pixel8
Author URI: http://www.wearepixel8.com
*/

// Add function to widgets_init that'll load this widget 
add_action( 'widgets_init', 'wap8_custom_categories_widget' );

// Register this widget
function wap8_custom_categories_widget() {
	register_widget( 'wap8_Custom_Categories_Widget' );
}

// Extend WP_Widget by adding this widget class
class wap8_Custom_Categories_Widget extends WP_Widget {

	// Widget setup
	function wap8_Custom_Categories_Widget() {
		$widget_ops = array(
			'classname' => 'wap8_custom_categories_widget',
			'description' => __( 'Display a customized categories list with post count.', 'periodic' )
			);
			
		$this->WP_Widget('wap8-custom-categories-widget', __( 'Periodic Custom Categories', 'periodic' ), $widget_ops);	
	}
	
	// Saved widget display
	function widget( $args, $instance ) {
		extract($args);
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		$cattext = $instance['cattext'];
		
		echo $before_widget;
		echo $before_title . $title . $after_title;

		echo '<ul class="category-link-list">';
		$variable = wp_list_categories('echo=0&show_count=1&title_li=&orderby=name&depth=1');
		$variable = str_replace(array('(',')'), array('', __('<span>' . $cattext . '</span>' )), $variable);
		echo $variable;
		echo '</ul>';

		echo $after_widget;	
	}
	
	// Update widget
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['cattext'] = strip_tags( $new_instance['cattext'] );
		return $instance;
	}
	
	// Widget form
	function form( $instance ) {
		$defaults = array(
			'title' => __( 'Browse by Categories', 'periodic' ),
			'cattext'=> __( 'Articles', 'periodic' )
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'periodic' ); ?></label><br />
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title'];?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'cattext' ); ?>"><?php _e( 'Post Count Text', 'periodic' ); ?></label><br />
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'cattext' ); ?>" name="<?php echo $this->get_field_name( 'cattext' ); ?>" value="<?php echo $instance['cattext'];?>" />
		</p>
		
		<p><small><?php _e('<strong>Note:</strong> This widget will display a custom list of your top level categories with a post count. <strong>This widget is intended for sidebar use only.</strong>','periodic'); ?></small></p>		
		<?php	
	}

}

?>