<?php

/*
Plugin Name: Flickr Feed Widget
Plugin URI: http://www.wearepixel8.com
Description: A widget that will display recent images from a designated Flickr account.
Version: 1.0
Author: We Are Pixel8
Author URI: http://www.wearepixel8.com
*/

// Add function to widgets_init that'll load this widget 
add_action( 'widgets_init', 'wap8_flickr_feed_widget' );

// Register this widget
function wap8_flickr_feed_widget() {
	register_widget( 'wap8_Flickr_Widget' );
}

// Extend WP_Widget by adding this widget class
class wap8_Flickr_Widget extends WP_Widget {

	// Widget setup
	function wap8_Flickr_Widget() {
		$widget_ops = array(
			'classname' => 'wap8_flickr_widget',
			'description' => __( 'Display recent images from a designated Flickr account.', 'periodic' )
			);
			
		$this->WP_Widget('wap8-Flickr-widget', __( 'Periodic Flickr Feed', 'periodic' ), $widget_ops);	
	}
	
	// Saved widget display
	function widget( $args, $instance ) {
		extract($args);
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		$flickr_id = $instance['flickr_id'];
		$flickr_count = $instance['flickr_count'];
		
		echo $before_widget;
		echo $before_title . $title . $after_title;
		
		?>
			<?php
				include_once( ABSPATH . WPINC . '/feed.php' );
				locate_template( '/scripts/flickr.php', true, true );

				$rss = fetch_feed('http://api.flickr.com/services/feeds/photos_public.gne?id=' . $flickr_id . '&lang=en-us&format=rss_200');
				$thumb = 'square';
				$full = 'medium';

				$maxitems = $rss->get_item_quantity($flickr_count); 

				$rss_items = $rss->get_items(0, $maxitems); 
			?>
				<ul class="flickr-feed clear"><!-- Begin flickr feed -->
				<?php if ($maxitems == 0) echo '<li>No items.</li>';
				else

				foreach ( $rss_items as $item ):
  					$url = flickr::find_photo($item->get_description());
  					$title = flickr::cleanup($item->get_title());
  					$full_url = flickr::photo($url, $full);
  					$thumb_url = flickr::photo($url, $thumb);
				?>
					<li><a href="<?php echo $item->get_permalink(); ?>" title="<?php echo $item->get_title(); ?>"><img src="<?php echo $thumb_url; ?>" alt="<?php echo $item->get_title(); ?>" width="75" height="75" /></a></li>

				<?php endforeach; ?>	
				</ul>		
		<?php		
		
		echo $after_widget;		
	}
	
	// Update widget
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['flickr_id'] = strip_tags( $new_instance['flickr_id'] );
		$instance['flickr_count'] = (int) $new_instance['flickr_count'];
		return $instance;
	}
	
	// Widget form
	function form( $instance ) {
		$defaults = array(
			'title' => __( 'Flickr Feed', 'periodic' )
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		if ( (int) $instance['flickr_count'] < 1 )
			(int) $intsance['flickr_count'] = 6;
		else if ( (int) $instance['flickr_count'] > 12 )
			(int) $instance['flickr_count'] = 12;

		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'periodic' ); ?></label><br />
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title'];?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'flickr_id' ); ?>"><?php _e( 'Flickr ID', 'periodic' ); ?> &#40;<a href=<?php echo wap8_flickr_idgettr_url(); ?> target="_blank" title="<?php _e( 'Find your Flickr ID using idGettr', 'periodic' ); ?>"><?php _e( 'idGettr', 'periodic' ); ?></a>&#41;</label><br />
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'flickr_id' ); ?>" name="<?php echo $this->get_field_name( 'flickr_id' ); ?>" value="<?php echo $instance['flickr_id'];?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'flickr_count' ); ?>"><?php _e( 'Images to Show', 'periodic' ); ?></label>
			<input type="text" id="<?php echo $this->get_field_id( 'flickr_count' ); ?>" name="<?php echo $this->get_field_name( 'flickr_count' ); ?>" value="<?php echo $instance['flickr_count'];?>" size="3" maxlength="2" /> <small><?php _e( 'Max: 12', 'periodic' ); ?></small>
		</p>

		<?php	
	}
	
}

?>