<?php

/*
Plugin Name: Tabbed Content Widget
Plugin URI: http://www.wearepixel8.com
Description: A widget that will display your popular posts, recent posts and popular tags, in a tabbed format, in your sidebar.
Version: 1.0
Author: We Are Pixel8
Author URI: http://www.wearepixel8.com
*/

// Add function to widgets_init that'll load this widget 
add_action( 'widgets_init', 'wap8_tabs_widget' );

// Register this widget
function wap8_tabs_widget() {
	register_widget( 'wap8_Tabs_Widget' );
}

// Extend WP_Widget by adding this widget class
class wap8_Tabs_Widget extends WP_Widget {

	// Widget setup
	function wap8_Tabs_Widget() {
		$widget_ops = array(
			'classname' => 'wap8_tabs_widget',
			'description' => __( 'Display a tabbed content widget for your popular posts, recent posts and popular tags.', 'periodic' )
			);
			
		$this->WP_Widget('wap8-tabs-widget', __( 'Periodic Tabs Widget', 'periodic' ), $widget_ops);	
	}
	
	// Saved widget display
	function widget( $args, $instance ) {
		extract($args);
		
		$postcount = $instance['postcount'];
		$tagcount = $instance['tagcount'];
		
		?>

		<div id="tab-container"><!-- Begin tab container -->
			<ul class="tab-nav clear">
				<li><a href="#popular" title="<?php _e('Popular','periodic'); ?>"><?php _e('Popular','periodic'); ?></a></li>
				<li><a href="#recent" title="<?php _e('Recent','periodic'); ?>"><?php _e('Recent','periodic'); ?></a></li>
				<li><a href="#tags" title="<?php _e('Tags','periodic'); ?>"><?php _e('Tags','periodic'); ?></a></li>
			</ul>
	
			<div id="popular" class="tab-body"><!-- Begin popular posts -->
				<ul class="sidebar-archive">
				<?php $pp = new WP_Query('orderby=comment_count&posts_per_page=' . $postcount );
					while ($pp->have_posts()) : $pp->the_post(); ?>								
					<li>
						<div class="sidebar-archive-thumb">
						<?php if ( has_post_thumbnail() ) { ?>
							<a href="<?php echo get_permalink($postid); ?>" title="<?php the_title_attribute(); ?>"><?php the_post_thumbnail('thumbnail-sidebar', array('title' => get_the_title())); ?></a>
						<?php } else { ?>
							<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><img src="<?php echo get_template_directory_uri(); ?>/images/thumbnails/thumbnail-sidebar.jpg" width="60" height="60" alt="<?php the_title_attribute(); ?>" /></a>
						<?php } ?>
						</div>
						<div class="sidebar-archive-text">
							<h4><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<p><?php comments_number(__('No Comments','periodic'),__('1 Comment','periodic'),__('% Comments','periodic')); ?></p>
						</div>	
					</li>
				<?php endwhile; wp_reset_query(); ?>

				</ul>
			</div><!-- End popular posts -->
	
			<div id="recent" class="tab-body"><!-- Begin recent posts -->
				<ul class="sidebar-archive">
					<?php $recent_articles = new WP_Query('orderby=post_date&order=DESC&caller_get_posts=1&posts_per_page=' . $postcount );
					while ( $recent_articles -> have_posts() ) : $recent_articles -> the_post(); ?>
					<li>
						<div class="sidebar-archive-thumb">
						<?php if ( has_post_thumbnail() ) { ?>
							<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_post_thumbnail('thumbnail-sidebar', array('title' => get_the_title())); ?></a>
						<?php } else { ?>
							<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><img src="<?php echo get_template_directory_uri(); ?>/images/thumbnails/thumbnail-sidebar.jpg" width="60" height="60" alt="<?php the_title_attribute(); ?>" /></a>
						<?php } ?>
						</div>
						<div class="sidebar-archive-text">
							<h4><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<p><?php the_time('F d, Y'); ?></p>
						</div>							
					</li>
					<?php endwhile; wp_reset_query(); ?>
				</ul>
			</div><!-- End recent posts -->
	
			<div id="tags" class="tab-body"><!-- Begin tags -->
				<?php wp_tag_cloud('smallest=1.1&largest=1.1&format=list&unit=em&orderby=count&order=ASC&number=' . $tagcount ); ?>
			</div><!-- End tags -->
		</div><!-- End tab container -->
		
		<?php		
		
	}
	
	// Update widget
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['postcount'] = (int) $new_instance['postcount'];
		$instance['tagcount'] = (int) $new_instance['tagcount'];
		return $instance;
	}
	
	// Widget form
	function form( $instance ) {

		if ( (int) $instance['postcount'] < 1 )
			(int) $intsance['postcount'] = 5;
		else if ( (int) $instance['postcount'] > 20 )
			(int) $instance['postcount'] = 20;
			
		if ( (int) $instance['tagcount'] < 1 )
			(int) $intsance['tagcount'] = 10;
		else if ( (int) $instance['tagcount'] > 50 )
			(int) $instance['tagcount'] = 50;
			
		?>
		
		<p><small><?php _e('Use this widget to display Popular Posts, Recent Posts and Popular Tags, in a jQuery tabbed format, in your sidebar. You will be able to set how many posts and tags to display. <strong>This widget is intended for sidebar use only.</strong>','periodic'); ?></small></p>
		
		<p>
			<label for="<?php echo $this->get_field_id('postcount'); ?>"><?php _e('Posts to Show','periodic'); ?></label>
			<input type="text" id="<?php echo $this->get_field_id('postcount'); ?>" name="<?php echo $this->get_field_name('postcount'); ?>" value="<?php echo $instance['postcount'];?>" size="3" maxlength="2" /> <small><?php _e('Max: 20','periodic'); ?></small>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('tagcount'); ?>"><?php _e('Tags to Show','periodic'); ?></label>
			<input type="text" id="<?php echo $this->get_field_id('tagcount'); ?>" name="<?php echo $this->get_field_name('tagcount'); ?>" value="<?php echo $instance['tagcount'];?>" size="3" maxlength="2" /> <small><?php _e('Max: 50','periodic'); ?></small>
		</p>
		
		<?php
			
	}	

}

?>